@@ -41,6 +41,11 @@ Windows::Windows(AbstractWindowInterface *parent)
     m_updateApplicationDataTimer.setSingleShot(true);
     connect(&m_updateApplicationDataTimer, &QTimer::timeout, this, &Windows::updateApplicationData);
 
+    //! delayed update all hints
+    m_updateAllHintsTimer.setInterval(300);
+    m_updateAllHintsTimer.setSingleShot(true);
+    connect(&m_updateAllHintsTimer, &QTimer::timeout, this, &Windows::updateAllHints);
+
     init();
 }
 
@@ -108,7 +113,8 @@ void Windows::init()
     });
 
     connect(m_wm, &AbstractWindowInterface::currentDesktopChanged, this, &Windows::updateAllHints);
-    connect(m_wm, &AbstractWindowInterface::currentActivityChanged,  this, &Windows::updateAllHints);
+    connect(m_wm, &AbstractWindowInterface::currentActivityChanged,  this, &Windows::updateAllHints);    
+    connect(m_wm, &AbstractWindowInterface::isShowingDesktopChanged,  this, &Windows::updateAllHints);
 }
 
 void Windows::initLayoutHints(Latte::Layout::GenericLayout *layout)
@@ -168,6 +174,7 @@ void Windows::addView(Latte::View *view)
 
     connect(view, &Latte::View::isTouchingBottomViewAndIsBusyChanged, this, &Windows::updateExtraViewHints);
     connect(view, &Latte::View::isTouchingTopViewAndIsBusyChanged, this, &Windows::updateExtraViewHints);
+    connect(view, &Latte::View::absoluteGeometryChanged, this, &Windows::updateAllHintsAfterTimer);
 
     updateAllHints();
 
@@ -820,6 +827,14 @@ void Windows::updateScreenGeometries()
     }
 }
 
+void Windows::updateAllHintsAfterTimer()
+{
+    if (!m_updateAllHintsTimer.isActive()) {
+        updateAllHints();
+        m_updateAllHintsTimer.start();
+    }
+}
+
 void Windows::updateAllHints()
 {
     for (const auto view : m_views.keys()) {
@@ -903,6 +918,10 @@ void Windows::updateHints(Latte::View *view)
 
     //! First Pass
     for (const auto &winfo : m_windows) {
+        if (m_wm->isShowingDesktop()) {
+            break;
+        }
+
         if (!existsFaultyWindow && (winfo.wid()<=0 || winfo.geometry() == QRect(0, 0, 0, 0))) {
             existsFaultyWindow = true;
         }
@@ -966,7 +985,7 @@ void Windows::updateHints(Latte::View *view)
     }
 
     //! PASS 2
-    if (foundActiveInCurScreen && !foundActiveTouchInCurScreen) {
+    if (!m_wm->isShowingDesktop() && foundActiveInCurScreen && !foundActiveTouchInCurScreen) {
         //! Second Pass to track also Child windows if needed
 
         //qDebug() << "Windows Array...";
@@ -1069,6 +1088,10 @@ void Windows::updateHints(Latte::Layout::GenericLayout *layout) {
     WindowId maxWinId;
 
     for (const auto &winfo : m_windows) {
+        if (m_wm->isShowingDesktop()) {
+            break;
+        }
+
         if (!existsFaultyWindow && (winfo.wid()<=0 || winfo.geometry() == QRect(0, 0, 0, 0))) {
             existsFaultyWindow = true;
         }
